Olá, você está recebendo este email pois solicitou uma recuperação de senha.<br>
Para escolher uma nova senha, clique neste <a href="{{link}}">link</a>. O link é válido por 24 horas.<br>
<br>
Caso não tenha solicitado a alteração, ignore este email.
